/* automatically generated from keyboard-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (keyboard_dialog_ui)
#endif
#ifdef __GNUC__
static const char keyboard_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char keyboard_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"2.20\"/><object class=\"GtkImage\" id=\"image1\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"stock\">gtk-revert-to-saved</property></objec"
  "t><object class=\"XfceTitledDialog\" id=\"keyboard-layout-selection-dia"
  "log\"><property name=\"can_focus\">False</property><property name=\"tit"
  "le\" translatable=\"yes\">Keyboard layout selection</property><property"
  " name=\"window_position\">center-on-parent</property><property name=\"d"
  "efault_height\">300</property><property name=\"icon_name\">preferences-"
  "desktop-keyboard</property><property name=\"type_hint\">dialog</propert"
  "y><property name=\"subtitle\" translatable=\"yes\">Select keyboard layo"
  "ut and variant</property><child internal-child=\"vbox\"><object class=\""
  "GtkVBox\" id=\"dialog-vbox2\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"spacing\""
  ">2</property><child internal-child=\"action_area\"><object class=\"GtkH"
  "ButtonBox\" id=\"dialog-action_area2\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "layout_style\">end</property><child><object class=\"GtkButton\" id=\"la"
  "yout_selection_ok_button\"><property name=\"label\">gtk-ok</property><p"
  "roperty name=\"use_action_appearance\">False</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"use_s"
  "tock\">True</property></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">False</property><property name=\"pos"
  "ition\">0</property></packing></child><child><object class=\"GtkButton\""
  " id=\"layout_selection_cancel_button\"><property name=\"label\">gtk-can"
  "cel</property><property name=\"use_action_appearance\">False</property>"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "True</property><property name=\"receives_default\">True</property><prop"
  "erty name=\"use_stock\">True</property></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">False</property><pr"
  "operty name=\"position\">1</property></packing></child></object><packin"
  "g><property name=\"expand\">False</property><property name=\"fill\">Tru"
  "e</property><property name=\"pack_type\">end</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkScro"
  "lledWindow\" id=\"scrolledwindow3\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">True</property><property name=\"bor"
  "der_width\">6</property><property name=\"hscrollbar_policy\">automatic<"
  "/property><property name=\"vscrollbar_policy\">automatic</property><pro"
  "perty name=\"shadow_type\">in</property><child><object class=\"GtkTreeV"
  "iew\" id=\"layout_selection_view\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"head"
  "ers_visible\">False</property><property name=\"search_column\">0</prope"
  "rty></object></child></object><packing><property name=\"expand\">True</"
  "property><property name=\"fill\">True</property><property name=\"positi"
  "on\">1</property></packing></child></object></child><action-widgets><ac"
  "tion-widget response=\"1\">layout_selection_ok_button</action-widget><a"
  "ction-widget response=\"0\">layout_selection_cancel_button</action-widg"
  "et></action-widgets></object><object class=\"XfceTitledDialog\" id=\"ke"
  "yboard-settings-dialog\"><property name=\"can_focus\">False</property><"
  "property name=\"title\" translatable=\"yes\">Keyboard</property><proper"
  "ty name=\"window_position\">center-on-parent</property><property name=\""
  "default_width\">400</property><property name=\"icon_name\">preferences-"
  "desktop-keyboard</property><property name=\"type_hint\">dialog</propert"
  "y><property name=\"subtitle\" translatable=\"yes\">Edit keyboard settin"
  "gs and application shortcuts</property><child internal-child=\"vbox\"><"
  "object class=\"GtkVBox\" id=\"dialog-vbox1\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"spacing\">2</property><child internal-child=\"action_area\"><obj"
  "ect class=\"GtkHButtonBox\" id=\"dialog-action_area1\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"layout_style\">end</property><child><object class=\"Gtk"
  "Button\" id=\"button2\"><property name=\"label\">gtk-close</property><p"
  "roperty name=\"use_action_appearance\">False</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"use_s"
  "tock\">True</property></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">False</property><property name=\"pos"
  "ition\">0</property></packing></child><child><object class=\"GtkButton\""
  " id=\"button1\"><property name=\"label\">gtk-help</property><property n"
  "ame=\"use_action_appearance\">False</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">True</property><property name=\"use_stock\">Tr"
  "ue</property></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">False</property><property name=\"position\">0"
  "</property><property name=\"secondary\">True</property></packing></chil"
  "d></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"pack_type\">end</propert"
  "y><property name=\"position\">0</property></packing></child><child><obj"
  "ect class=\"GtkVBox\" id=\"plug-child\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"border_width\">6</property><property name=\"spacing\">6</property><ch"
  "ild><object class=\"GtkNotebook\" id=\"notebook1\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><chil"
  "d><object class=\"GtkVBox\" id=\"vbox3\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"border_width\">12</property><property name=\"spacing\">6</property><"
  "child><object class=\"GtkFrame\" id=\"frame1\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"label_xalign\">0</property><property name=\"shadow_type\">none"
  "</property><child><object class=\"GtkAlignment\" id=\"alignment5\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"top_padding\">6</property><property name=\""
  "bottom_padding\">6</property><property name=\"left_padding\">18</proper"
  "ty><property name=\"right_padding\">6</property><child><object class=\""
  "GtkCheckButton\" id=\"restore_numlock\"><property name=\"label\" transl"
  "atable=\"yes\">Restore num l_ock state on startup</property><property n"
  "ame=\"use_action_appearance\">False</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">False</property><property name=\"use_underline"
  "\">True</property><property name=\"draw_indicator\">True</property></ob"
  "ject></child></object></child><child type=\"label\"><object class=\"Gtk"
  "Label\" id=\"label9\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"label\" translat"
  "able=\"yes\">General</property><property name=\"use_markup\">True</prop"
  "erty><attributes><attribute name=\"weight\" value=\"bold\"/></attribute"
  "s></object></child></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">0</property></packing></child><child><object class=\"GtkFrame\" id="
  "\"frame2\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"label_xalign\">0</property>"
  "<property name=\"shadow_type\">none</property><child><object class=\"Gt"
  "kAlignment\" id=\"alignment2\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"left_pa"
  "dding\">12</property><child><object class=\"GtkVBox\" id=\"vbox1\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"border_width\">6</property><property name="
  "\"spacing\">6</property><child><object class=\"GtkCheckButton\" id=\"xk"
  "b_key_repeat_check\"><property name=\"label\" translatable=\"yes\">_Ena"
  "ble key repeat</property><property name=\"use_action_appearance\">False"
  "</property><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"receives_default\">False</pr"
  "operty><property name=\"tooltip_text\" translatable=\"yes\">When select"
  "ed, pressing and holding down a key emits the same character over and o"
  "ver again</property><property name=\"use_underline\">True</property><pr"
  "operty name=\"active\">True</property><property name=\"draw_indicator\""
  ">True</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">False</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkAlignment\" id"
  "=\"xkb_key_repeat_box\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"left_padding\""
  ">18</property><child><object class=\"GtkVBox\" id=\"vbox6\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"spacing\">6</property><child><object class=\"GtkL"
  "abel\" id=\"label7\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"xalign\">0</prope"
  "rty><property name=\"label\" translatable=\"yes\">_Repeat delay:</prope"
  "rty><property name=\"use_underline\">True</property><property name=\"mn"
  "emonic_widget\">xkb_key_repeat_delay_scale</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">False"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkHScale\" id=\"xkb_key_repeat_delay_scale\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"tooltip_text\" translatable=\"yes\">The tim"
  "e, in milliseconds, before a pressed key begins repeating</property><pr"
  "operty name=\"update_policy\">delayed</property><property name=\"adjust"
  "ment\">xkb_key_repeat_delay</property><property name=\"digits\">0</prop"
  "erty><property name=\"value_pos\">right</property></object><packing><pr"
  "operty name=\"expand\">True</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">1</property></packing></child><child>"
  "<object class=\"GtkLabel\" id=\"label10\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"xalign\">0</property><property name=\"label\" translatable=\"yes\">"
  "Repeat _speed:</property><property name=\"use_underline\">True</propert"
  "y><property name=\"mnemonic_widget\">xkb_key_repeat_rate_scale</propert"
  "y></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">False</property><property name=\"position\">2</property>"
  "</packing></child><child><object class=\"GtkHScale\" id=\"xkb_key_repea"
  "t_rate_scale\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"tooltip_text\" translata"
  "ble=\"yes\">The rate at which keystrokes are generated while a key is p"
  "ressed</property><property name=\"update_policy\">delayed</property><pr"
  "operty name=\"adjustment\">xkb_key_repeat_rate</property><property name"
  "=\"digits\">0</property><property name=\"value_pos\">right</property></"
  "object><packing><property name=\"expand\">True</property><property name"
  "=\"fill\">True</property><property name=\"position\">3</property></pack"
  "ing></child></object></child></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object></child></object></ch"
  "ild><child type=\"label\"><object class=\"GtkLabel\" id=\"label5\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"label\" translatable=\"yes\">Typing Settin"
  "gs</property><attributes><attribute name=\"weight\" value=\"bold\"/></a"
  "ttributes></object></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">False</property><property name="
  "\"position\">1</property></packing></child><child><object class=\"GtkFr"
  "ame\" id=\"frame3\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"label_xalign\">0</"
  "property><property name=\"shadow_type\">none</property><child><object c"
  "lass=\"GtkAlignment\" id=\"alignment3\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"left_padding\">12</property><child><object class=\"GtkVBox\" id=\"vbo"
  "x4\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"border_width\">6</property><prope"
  "rty name=\"spacing\">6</property><child><object class=\"GtkCheckButton\""
  " id=\"net_cursor_blink_check\"><property name=\"label\" translatable=\""
  "yes\">Show _blinking</property><property name=\"use_action_appearance\""
  ">False</property><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">True</property><property name=\"receives_default\">Fal"
  "se</property><property name=\"tooltip_text\" translatable=\"yes\">Speci"
  "fy whether or not the text cursor blinks</property><property name=\"use"
  "_underline\">True</property><property name=\"draw_indicator\">True</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">False</property><property name=\"position\">0</prope"
  "rty></packing></child><child><object class=\"GtkAlignment\" id=\"net_cu"
  "rsor_blink_box\"><property name=\"visible\">True</property><property na"
  "me=\"sensitive\">False</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"left_padding\">18</property><child><object clas"
  "s=\"GtkVBox\" id=\"vbox7\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"spacing\">6"
  "</property><child><object class=\"GtkLabel\" id=\"label13\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"xalign\">0</property><property name=\"label\" tra"
  "nslatable=\"yes\">Blink _delay:</property><property name=\"use_underlin"
  "e\">True</property><property name=\"mnemonic_widget\">net_cursor_blink_"
  "time_scale</property></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">False</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkHScale\""
  " id=\"net_cursor_blink_time_scale\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">True</property><property name=\"too"
  "ltip_text\" translatable=\"yes\">The delay, in milliseconds, between su"
  "ccessive blinks of the cursor</property><property name=\"update_policy\""
  ">delayed</property><property name=\"adjustment\">net_cursor_blink_time<"
  "/property><property name=\"digits\">0</property><property name=\"value_"
  "pos\">right</property></object><packing><property name=\"expand\">True<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">1</property></packing></child></object></child></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">1</property></packing></child></o"
  "bject></child></object></child><child type=\"label\"><object class=\"Gt"
  "kLabel\" id=\"label6\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">Cursor</property><attributes><attribute name=\"weight\" v"
  "alue=\"bold\"/></attributes></object></child></object><packing><propert"
  "y name=\"expand\">True</property><property name=\"fill\">True</property"
  "><property name=\"position\">2</property></packing></child><child><obje"
  "ct class=\"GtkHBox\" id=\"hbox1\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"spac"
  "ing\">12</property><child><object class=\"GtkLabel\" id=\"label12\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"label\" translatable=\"yes\">_Test area:<"
  "/property><property name=\"use_underline\">True</property><property nam"
  "e=\"mnemonic_widget\">entry1</property></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">0</property></packing></child><child><object cl"
  "ass=\"GtkEntry\" id=\"entry1\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">True</property><property name=\"invisibl"
  "e_char\">\342\200\242</property><property name=\"invisible_char_set\">T"
  "rue</property><property name=\"primary_icon_activatable\">False</proper"
  "ty><property name=\"secondary_icon_activatable\">False</property><prope"
  "rty name=\"primary_icon_sensitive\">True</property><property name=\"sec"
  "ondary_icon_sensitive\">True</property></object><packing><property name"
  "=\"expand\">True</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">1</property></packing></child></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">3</property></packing></child></o"
  "bject></child><child type=\"tab\"><object class=\"GtkLabel\" id=\"label"
  "2\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">False</property><property name=\"label\" translatable=\"yes\">Be_ha"
  "vior</property><property name=\"use_underline\">True</property></object"
  "><packing><property name=\"tab_fill\">False</property></packing></child"
  "><child><object class=\"GtkVBox\" id=\"vbox5\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"border_width\">12</property><property name=\"spacing\">6</prop"
  "erty><child><object class=\"GtkLabel\" id=\"label16\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"xalign\">0</property><property name=\"label\" translata"
  "ble=\"yes\">Define _shortcuts for launching applications:</property><pr"
  "operty name=\"use_underline\">True</property><property name=\"mnemonic_"
  "widget\">kbd_shortcuts_view</property></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">False</property><pro"
  "perty name=\"position\">0</property></packing></child><child><object cl"
  "ass=\"GtkScrolledWindow\" id=\"scrolledwindow2\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"hscrollbar_policy\">automatic</property><property name=\"vscr"
  "ollbar_policy\">automatic</property><property name=\"shadow_type\">etch"
  "ed-in</property><child><object class=\"GtkTreeView\" id=\"kbd_shortcuts"
  "_view\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"search_column\">0</property></o"
  "bject></child></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">1<"
  "/property></packing></child><child><object class=\"GtkHBox\" id=\"hbox2"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">False</property><property name=\"spacing\">12</property><child><obje"
  "ct class=\"GtkButton\" id=\"add_shortcut_button\"><property name=\"labe"
  "l\">gtk-add</property><property name=\"use_action_appearance\">False</p"
  "roperty><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"receives_default\">True</proper"
  "ty><property name=\"use_stock\">True</property></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">False</prop"
  "erty><property name=\"position\">0</property></packing></child><child><"
  "object class=\"GtkButton\" id=\"delete_shortcut_button\"><property name"
  "=\"label\">gtk-remove</property><property name=\"use_action_appearance\""
  ">False</property><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">True</property><property name=\"receives_default\">Tru"
  "e</property><property name=\"use_stock\">True</property></object><packi"
  "ng><property name=\"expand\">False</property><property name=\"fill\">Fa"
  "lse</property><property name=\"position\">1</property></packing></child"
  "><child><object class=\"GtkButton\" id=\"reset_shortcuts_button\"><prop"
  "erty name=\"label\" translatable=\"yes\">Reset to _Defaults</property><"
  "property name=\"use_action_appearance\">False</property><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<property name=\"receives_default\">True</property><property name=\"ima"
  "ge\">image1</property><property name=\"use_underline\">True</property><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">False</property><property name=\"position\">2</property></p"
  "acking></child></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"fill\">True</property><property name=\"position\">"
  "2</property></packing></child></object><packing><property name=\"positi"
  "on\">1</property></packing></child><child type=\"tab\"><object class=\""
  "GtkLabel\" id=\"label3\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"label\" trans"
  "latable=\"yes\">A_pplication Shortcuts</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"position\""
  ">1</property><property name=\"tab_fill\">False</property></packing></ch"
  "ild><child><object class=\"GtkVBox\" id=\"xkb_tab_layout_vbox\"><proper"
  "ty name=\"can_focus\">False</property><property name=\"border_width\">1"
  "2</property><property name=\"spacing\">6</property><child><object class"
  "=\"GtkCheckButton\" id=\"xkb_use_system_default_checkbutton\"><property"
  " name=\"label\" translatable=\"yes\">_Use system defaults</property><pr"
  "operty name=\"use_action_appearance\">False</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">False</property><property name=\"tool"
  "tip_text\" translatable=\"yes\">Specifies whether the keyboard layout i"
  "s controlled with this settings dialog, or by the X server</property><p"
  "roperty name=\"use_underline\">True</property><property name=\"active\""
  ">True</property><property name=\"draw_indicator\">True</property></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">False</property><property name=\"position\">0</property></packin"
  "g></child><child><object class=\"GtkFrame\" id=\"xkb_model_frame\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"label_xalign\">0</property><property name="
  "\"shadow_type\">none</property><child><object class=\"GtkAlignment\" id"
  "=\"alignment1\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"border_width\">6</prop"
  "erty><property name=\"left_padding\">12</property><child><object class="
  "\"GtkComboBox\" id=\"xkb_model_combo\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property></object></child"
  "></object></child><child type=\"label\"><object class=\"GtkLabel\" id=\""
  "label11\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">Keyboard model</property><attributes><attribute name=\"weight\" value="
  "\"bold\"/></attributes></object></child></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">1</property></packing></child><child><object c"
  "lass=\"GtkFrame\" id=\"xkb_layout_frame\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"label_xalign\">0</property><property name=\"shadow_type\">none</pro"
  "perty><child><object class=\"GtkAlignment\" id=\"alignment4\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"left_padding\">12</property><child><object clas"
  "s=\"GtkVBox\" id=\"vbox8\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"border_widt"
  "h\">6</property><property name=\"spacing\">6</property><child><object c"
  "lass=\"GtkScrolledWindow\" id=\"scrolledwindow1\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"hscrollbar_policy\">automatic</property><property name=\"vsc"
  "rollbar_policy\">automatic</property><property name=\"shadow_type\">etc"
  "hed-in</property><child><object class=\"GtkTreeView\" id=\"xkb_layout_v"
  "iew\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">True</property><property name=\"search_column\">0</property></obj"
  "ect></child></object><packing><property name=\"expand\">True</property>"
  "<property name=\"fill\">True</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkHButtonBox\" id=\"h"
  "buttonbox2\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"spacing\">12</property><pr"
  "operty name=\"layout_style\">start</property><child><object class=\"Gtk"
  "Button\" id=\"xkb_layout_add_button\"><property name=\"label\">gtk-add<"
  "/property><property name=\"use_action_appearance\">False</property><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"receives_default\">True</property><property"
  " name=\"use_stock\">True</property></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">False</property><proper"
  "ty name=\"position\">0</property></packing></child><child><object class"
  "=\"GtkButton\" id=\"xkb_layout_edit_button\"><property name=\"label\">g"
  "tk-edit</property><property name=\"use_action_appearance\">False</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">True</property><"
  "property name=\"use_stock\">True</property></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">False</property"
  "><property name=\"position\">1</property></packing></child><child><obje"
  "ct class=\"GtkButton\" id=\"xkb_layout_delete_button\"><property name=\""
  "label\">gtk-delete</property><property name=\"use_action_appearance\">F"
  "alse</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"use_stock\">True</property></object><packing"
  "><property name=\"expand\">False</property><property name=\"fill\">Fals"
  "e</property><property name=\"position\">2</property></packing></child><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">True</property><property name=\"position\">1</property></pa"
  "cking></child></object></child></object></child><child type=\"label\"><"
  "object class=\"GtkLabel\" id=\"label8\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label\" translatable=\"yes\">Keyboard layout</property><attributes><a"
  "ttribute name=\"weight\" value=\"bold\"/></attributes></object></child>"
  "</object><packing><property name=\"expand\">True</property><property na"
  "me=\"fill\">True</property><property name=\"position\">2</property></pa"
  "cking></child></object><packing><property name=\"position\">2</property"
  "></packing></child><child type=\"tab\"><object class=\"GtkLabel\" id=\""
  "label4\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "_Layout</property><property name=\"use_underline\">True</property></obj"
  "ect><packing><property name=\"position\">2</property><property name=\"t"
  "ab_fill\">False</property></packing></child></object><packing><property"
  " name=\"expand\">True</property><property name=\"fill\">True</property>"
  "<property name=\"position\">1</property></packing></child></object><pac"
  "king><property name=\"expand\">True</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">1</property></packing></child"
  "></object></child><action-widgets><action-widget response=\"0\">button2"
  "</action-widget><action-widget response=\"-11\">button1</action-widget>"
  "</action-widgets></object><object class=\"GtkAdjustment\" id=\"net_curs"
  "or_blink_time\"><property name=\"lower\">100</property><property name=\""
  "upper\">2000</property><property name=\"value\">1000</property><propert"
  "y name=\"step_increment\">1</property><property name=\"page_increment\""
  ">10</property></object><object class=\"GtkSizeGroup\" id=\"sizegroup1\""
  "><widgets><widget name=\"add_shortcut_button\"/><widget name=\"delete_s"
  "hortcut_button\"/></widgets></object><object class=\"GtkAdjustment\" id"
  "=\"xkb_key_repeat_delay\"><property name=\"lower\">10</property><proper"
  "ty name=\"upper\">1000</property><property name=\"value\">500</property"
  "><property name=\"step_increment\">1</property><property name=\"page_in"
  "crement\">10</property></object><object class=\"GtkAdjustment\" id=\"xk"
  "b_key_repeat_rate\"><property name=\"lower\">1</property><property name"
  "=\"upper\">250</property><property name=\"value\">20</property><propert"
  "y name=\"step_increment\">1</property><property name=\"page_increment\""
  ">10</property></object></interface>"
};

static const unsigned keyboard_dialog_ui_length = 28087u;

